<div class="marquee">
  <div class="about-image-container">
    <% partial('_image.ejs.html', { about, imgOpts: {} }) %>
  </div>
  <div class="about-contents">
    <%= about.title %> <%= about.body %> <% if (about.links) { %>
    <div class="about-footer"><% partial('_links.ejs.html', { about }) %></div>
    <% } %>
  </div>
</div>
