$wnd.rstudio.runAsyncCallback15("function q0i(){}\nfunction o0i(a){this.a=a}\nfunction t0i(a){this.a=a}\nfunction v0i(a){this.a=a}\nfunction v1i(a){this.a=a}\nfunction L_i(a){this.a=a}\nfunction w9f(a){this.a=a}\nfunction q_i(a){C_i(a,new t0i(a))}\nfunction v_i(a){U7f(a.b,new v0i(a))}\nfunction u_i(a){GPk(a.n,new o0i(a),new q0i,ego)}\nfunction x_i(a){GPk(a.n,new j0i(a,XUn,false),new l0i,nno)}\nfunction z_i(a,b){$If(a.d,new jij(b,true),false)}\nfunction d8f(a,b){(O3d(b),b)&&B_i(a.a,yop,'')}\nfunction N_i(a,b){this.a=a;this.b=b;iEf.call(this)}\nfunction s0i(a,b){z_i(a.a,'devtools::load_all(\"'+b+'\")')}\nfunction d_h(a,b){z3h(a,Ypo,'devtools_load_all_path',new PH,b)}\nfunction C_i(a,b){a.c!=null?s0i(b,a.c):d_h(a.j,new N_i(a,b))}\nfunction w_i(a){a.J.BI();gn((_m(),$m),new L_i(a))}\nfunction J_i(){C_f.call(this,'Terminating Build...')}\nfunction U7f(a,b){G7f(a,xop,xop,X9f(a.i.b.package_dependencies,'roxygen'),t7f(a,'roxygen'),false,new w9f(b))}\nfunction n_i(a,b){var c,d;H1f(a.q.d,null);d=b.outputs;for(c=0;c<d.length;c++)M$i(a.q,d[c]);b.errors.length>0&&L$i(a.q,b.errors_base_dir,b.errors,false,0,true,b.type);b.running?tfe(a.a.Rj,true,false):G1f(a.q.d);x4e(a.q.d.c.c)}\nfunction r1i(a){try{if(a.c<0)return;if(!a.a.a){a.a.a=g2i(a.a.b.a);rQi(a.a,a.a.a)}switch(a.c){case 1:n_i(a.a.a,a.b[0]);break;case 2:a.a.a.J.zI();break;case 3:a.a.a.J.AI();break;case 4:B_i(a.a.a,w5o,'');break;case 5:B_i(a.a.a,'build-binary-package','');break;case 6:B_i(a.a.a,'build-source-package','');break;case 7:B_i(a.a.a,'check-package','');break;case 8:B_i(a.a.a,'clean-all','');break;case 9:u_i(a.a.a);break;case 10:B_i(a.a.a,x5o,'');break;case 11:v_i(a.a.a);break;case 12:w_i(a.a.a);break;case 13:x_i(a.a.a);break;case 14:A4h(a.a.a.j,new J_i);break;case 15:B_i(a.a.a,'test-package','');break;case 18:a.a.a.J.CI();}}finally{a.c<=0&&a.b[0]!=null&&a.b[0].gn()}}\nvar xop='Building package documentation',yop='roxygenize-package';E6c(2255,1,DSn,w9f);_.du=function x9f(a){d8f(this.a,a)};var Cmb=nQd(2255);E6c(7018,392,{},J_i);_.Wm=function K_i(a){(O3d(a),a)||W5c().SC(3,'Error Terminating Build','Unable to terminate build. Please try again.').TC()};var eYb=nQd(7018);E6c(7019,1,ISn,L_i);_.gn=function M_i(){x4e(this.a.q.d.c.c)};var fYb=nQd(7019);E6c(7020,54,{},N_i);_.kv=function O_i(a){this.a.c=a;s0i(this.b,this.a.c)};var gYb=nQd(7020);E6c(7011,1,ISn,o0i);_.gn=function p0i(){q_i(this.a)};var wYb=nQd(7011);E6c(7012,1,ISn,q0i);_.gn=function r0i(){};var xYb=nQd(7012);E6c(7010,1,DSn,t0i);_.du=function u0i(a){s0i(this,a)};var yYb=nQd(7010);E6c(7013,1,ISn,v0i);_.gn=function w0i(){B_i(this.a,yop,'')};var zYb=nQd(7013);E6c(254,1,gio);_.en=function u1i(){r1i((new v1i(this)).a)};E6c(6523,1,ISn,v1i);_.gn=function w1i(){r1i(this.a)};var VYb=nQd(6523);wJn(hm)(15);\n//# sourceURL=rstudio-15.js\n")
